@@ -1,6 +1,6 @@
 package Chemistry::File::Formula;
-$VERSION = '0.36';
-# $Id: Formula.pm,v 1.14 2005/09/20 14:06:50 itubert Exp $
+$VERSION = '0.37';
+# $Id: Formula.pm,v 1.16 2009/05/10 19:37:59 itubert Exp $
 
 use strict;
 use base "Chemistry::File";
@@ -159,6 +159,21 @@ which prints something like
 
 The C<parse_formula> method is called internally by the C<parse_string> method.
 
+=head3 Non-integer numbers in formulas
+
+The C<parse_formula> method can also accept formulas that contain
+floating-point numbers, such as H1.5N0.5. The numbers must be positive, and
+numbers smaller than one should include a leading zero (e.g., 0.9, not .9).
+
+When formulas with non-integer numbers of atoms are turned into molecule 
+objects as described in the previous section, the number of atoms is always
+B<rounded up>. For example, H1.5N0.5 will produce a molecule object with two
+hydrogen atoms and one nitrogen atom.
+
+There is currently no way of I<producing> formulas with non-integer numbers;
+perhaps a future version will include an "occupancy" property for atoms that
+will result in non-integer formulas.
+
 =cut
 
 sub parse_string {
@@ -260,7 +275,7 @@ sub parse_formula {
     }
 
     # determine initial compound coeficent
-    my $coef = ($formula =~ s/^(\d+)//) ? $1 : 1.0;
+    my $coef = ($formula =~ s/^(\d+\.?\d*)//) ? $1 : 1.0;
 
     # recursively process rest of formula
     return internal_formula_parser($formula, $coef, %elements);
@@ -275,7 +290,7 @@ sub internal_formula_parser {
 
     if (defined($extract) and $extract ne '') {
         $extract =~ s/^\((.*)\)$/$1/;
-        if ($remainder =~ s/^(\d+)(.*)$/$2/) {
+        if ($remainder =~ s/^(\d+\.?\d*)(.*)$/$2/) {
             $tmp_coef = $1 * $coef;
         } else {
             $tmp_coef = $coef;
@@ -303,9 +318,9 @@ sub add_formula_strings {
     my ($formula, $coef, %elements) = @_;
 
 #  print "Getting Formula of $formula\n";
-    $formula =~ /^(?:([A-Z][a-z]*)(\d+)?)+$/o
+    $formula =~ /^(?:([A-Z][a-z]*)(\d+\.?\d*)?)+$/o # XXX new
         or croak "Invalid Portion of Formula $formula";
-    while ($formula =~ m/([A-Z][a-z]*)(\d+)?/go) {
+    while ($formula =~ m/([A-Z][a-z]*)(\d+\.?\d*)?/go) { # XXX new
         my ($elm, $count) = ($1, $2);
         $count = 1 unless defined $count;
         if (defined $elements{$elm}) {
@@ -343,7 +358,7 @@ sub ParensBalanced {
 
 =head1 VERSION
 
-0.36
+0.37
 
 =head1 SEE ALSO
 
@@ -361,6 +376,8 @@ Ivan Tubert-Brohman <itub@cpan.org>.
 
 Formula parsing code contributed by Brent Gregersen.
 
+Patch for non-integer formulas by Daniel Scott.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2005 Ivan Tubert-Brohman. All rights reserved. This program is
